@@ -1,7 +1,6 @@
 #![feature(plugin_registrar, box_syntax, rustc_private)]
 #[macro_use] extern crate rustc;
 extern crate rustc_plugin;
-extern crate rustc_front;
 extern crate rustc_const_eval;
 extern crate syntax;
 
@@ -10,14 +9,15 @@ use rustc::lint::{LintPass, LateLintPass, LintArray, LateContext, LintContext};
 use rustc_const_eval::eval_const_expr;
 use rustc::middle::const_val::ConstVal::*;
 use rustc_plugin::registry::Registry;
-use rustc_front::hir;
+use rustc::hir;
 use syntax::ext::base::{ExtCtxt, MacResult, DummyResult, TTMacroExpander, MacEager};
 use syntax::ext::base::SyntaxExtension::NormalTT;
 use syntax::codemap::Span;
-use syntax::ast::{TokenTree, ItemKind};
+use syntax::ast::ItemKind;
 use syntax::parse::token::{intern, gensym_ident};
 use syntax::ext::build::AstBuilder;
 use syntax::feature_gate::AttributeType;
+use syntax::tokenstream::TokenTree;
 
 declare_lint!(STATIC_ASSERT, Deny,
               "check compile-time information");
@@ -36,7 +36,7 @@ impl LateLintPass for StaticAssertPass {
             return;
         }
         let evaluated = if let hir::ItemConst(_, ref expr) = it.node {
-            eval_const_expr(&cx.tcx, expr)
+            eval_const_expr(cx.tcx, expr)
         } else {
             return
         };
@@ -73,7 +73,7 @@ impl TTMacroExpander for StaticAssertMacro {
                 box MacEager {
                     items: Some(syntax::util::small_vector::SmallVector::one(item.clone())),
                     stmts: Some(syntax::util::small_vector::SmallVector::one(cx.stmt_item(sp, item.clone()))),
-                    expr: Some(cx.expr_block(cx.block(sp, vec![cx.stmt_item(sp, item)], None))),
+                    expr: Some(cx.expr_block(cx.block(sp, vec![cx.stmt_item(sp, item)]))),
                     .. MacEager::default()
                 }
             },
